#
# spec file for package libvirt-dbus
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libvirt-dbus
Version:        1.4.1
Release:        3.9
Summary:        D-Bus API binding for libvirt
License:        LGPL-2.1-or-later
URL:            https://libvirt.org/
Source0:        %{name}-%{version}.tar.xz
Source1:        system-user-%{name}.conf
BuildRequires:  gcc
BuildRequires:  meson
BuildRequires:  polkit
BuildRequires:  python3-docutils
BuildRequires:  sysuser-tools
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libvirt)
BuildRequires:  pkgconfig(libvirt-glib-1.0)
BuildRequires:  pkgconfig(systemd)
Requires:       polkit
Requires(pre):  user(libvirtdbus)
#!BuildIgnore:  user(libvirtdbus)

%description
This package provides D-Bus API for libvirt

%package -n system-user-libvirt-dbus
Summary:        System user for libvirt-dbus
Requires(pre):  group(libvirt)
BuildArch:      noarch
%sysusers_requires

%description -n system-user-libvirt-dbus
System user for libvirt-dbus.

%prep
%autosetup -p1

%build
%meson -Dinit_script=systemd
%meson_build
%sysusers_generate_pre %{SOURCE1} system-user-%{name} system-user-%{name}.conf

%install
%meson_install
mkdir -p %{buildroot}%{_sysusersdir}
install -m 0644 %{SOURCE1} %{buildroot}%{_sysusersdir}/system-user-%{name}.conf
ln -s service %{buildroot}%{_sbindir}/rclibvirt-dbus

%pre
%service_add_pre libvirt-dbus.service

%post
%service_add_post libvirt-dbus.service

%preun
%service_del_preun libvirt-dbus.service

%postun
%service_del_postun libvirt-dbus.service

%pre -n system-user-%{name} -f system-user-%{name}.pre

%files
%doc NEWS.rst
%license COPYING
%{_sbindir}/rclibvirt-dbus
%{_sbindir}/libvirt-dbus
%{_datadir}/dbus-1/services/org.libvirt.service
%{_datadir}/dbus-1/system-services/org.libvirt.service
%{_datadir}/dbus-1/system.d/org.libvirt.conf
%{_datadir}/dbus-1/interfaces/org.libvirt.*.xml
%{_datadir}/polkit-1/rules.d/libvirt-dbus.rules
%{_mandir}/man8/libvirt-dbus.8%{?ext_man}
%{_unitdir}/libvirt-dbus.service
%{_userunitdir}/libvirt-dbus.service

%files -n system-user-%{name}
%{_sysusersdir}/system-user-%{name}.conf

%changelog
* Sun Mar 20 2022 Callum Farmer <gmbr3@opensuse.org>
- Avoid self cycle due to user
* Fri Mar 11 2022 Callum Farmer <gmbr3@opensuse.org>
- Add CONFIG parameter to %%sysusers_generate_pre
* Fri Mar 11 2022 jfehlig@suse.com
- Update to version 1.4.1:
  * Release of libvirt-dbus 1.4.1
  * tests: allow running our tests against installed libvirt-dbus
  * tests: report proper error if `abs_top_builddir` is not defined
  * gitlab: use --fatal-meson-warnings in builds
  * meson: add git_werror option and only set if -Dwerror is not set
  * meson: honour meson warning_level setting
  * gitlab: adapt to use meson for libvirt-glib build
  * ci: refresh containers for CentOS-8 PowerTools repo rename
  * gitlab: replace "libvirt-" prefix with "ci-" in dockerfiles
  * gitlab: refresh containers with lcitool for fully minimized base
  * Dropped patches: libvirt-dbus-systemd.diff
- Add source service file
- Change system-user-libvirt-dbus subpackage to noarch
- Require libvirt group in system-user-libvirt-dbus subpackage
  bsc#1196968
* Wed May 26 2021 James Fehlig <jfehlig@suse.com>
- Add libvirtdbus user to libvirt group
  boo#1182538
* Mon Nov  9 2020 James Fehlig <jfehlig@suse.com>
- Fix syntax errors in system-user-libvirt-dbus.conf
  boo#1178530
* Mon Oct  5 2020 Ludwig Nussel <lnussel@suse.de>
- Actually require sysuser package
- Backport patch from git to autostart dbus interface using systemd
  (libvirt-dbus-systemd.diff)
* Tue Jul  7 2020 James Fehlig <jfehlig@suse.com>
- spec: Switch from explicitly adding user:group to sysuser
  mechanism
* Wed Jun 17 2020 Ludwig Nussel <lnussel@suse.de>
- initial package version 1.4.0
